const St = imports.gi.St;
const Lang = imports.lang;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const Panel = imports.ui.panel;
const Main = imports.ui.main;

const Gettext = imports.gettext;
const _ = Gettext.gettext;


function WorkspaceButton() {
   this._init();
}

WorkspaceButton.prototype = {
    __proto__: PanelMenu.SystemStatusButton.prototype,
   
    _init: function() {
        PanelMenu.SystemStatusButton.prototype._init.call(this, 'folder', _('Workspaces'));
        this.workspaceMenuItems = [];
      
        this._label = new St.Label({ text: (global.screen.get_active_workspace().index() + 1).toString(),
                                     style_class: 'workspaces-button'});
        this._iconActor = this._label;
        this.actor.set_child(this._iconActor);

        this._workspaceSection = new PopupMenu.PopupMenuSection();
        this.menu.addMenuItem(this._workspaceSection);
        this._createWorkspaceMenu();

        global.screen.connect_after('workspace-added', Lang.bind(this, this._createWorkspaceMenu));
        global.screen.connect_after('workspace-removed', Lang.bind(this, this._createWorkspaceMenu));
        global.screen.connect_after('workspace-switched', Lang.bind(this, this._updateWorkspaceButton));

        this.menu.actor.add_style_class_name('workspaces-menu')
        this.menu.actor.remove_style_class_name('popup-menu');

        let _children = Main.panel._rightBox.get_children();
        Main.panel._rightBox.insert_actor(this.actor, _children.length - 1);
        Main.panel._menus.addMenu(this.menu);
    },
   
    _updateWorkspaceButton: function(a, e){
        this._label.set_text((global.screen.get_active_workspace().index() + 1).toString());
    },
   
    _createWorkspaceMenu: function() {
       this._workspaceSection.removeAll();
       this.workspaceMenuItems = [];
      
       for (let i = 0; i < global.screen.n_workspaces; i++) {
           this.workspaceMenuItems[i] = new PopupMenu.PopupMenuItem((i + 1).toString());
           this._workspaceSection.addMenuItem(this.workspaceMenuItems[i]);
           this.workspaceMenuItems[i].workspaceId = i;
           this.workspaceMenuItems[i].label_actor = this._label;
           this.workspaceMenuItems[i].connect('activate', function(actor, event) {
               let thisWorkspace = global.screen.get_workspace_by_index(actor.workspaceId);
               thisWorkspace.activate(true);
               actor.label_actor.set_text((global.screen.get_active_workspace().index() + 1).toString());
           });
        }
    }
}

function main(extensionMeta) {
    let userExtensionLocalePath = extensionMeta.path + '/locale';
    Gettext.bindtextdomain("workspaces_button", userExtensionLocalePath);
    Gettext.textdomain("workspaces_button");

    new WorkspaceButton();
}

